from PySide6.QtWidgets import QWidget, QGridLayout
from qtconsole.manager import QtKernelManager
from qtconsole.rich_jupyter_widget import RichJupyterWidget


class IpythonWidget(QWidget):
    def __init__(self, kernel_name: str = "python3"):
        super().__init__()
        kernel_manager = QtKernelManager(kernel_name=kernel_name)
        kernel_manager.start_kernel()
        kernel_client = kernel_manager.client()
        kernel_client.start_channels()
        jupyter_widget = RichJupyterWidget()
        jupyter_widget.kernel_manager = kernel_manager
        jupyter_widget.kernel_client = kernel_client
        self.jupyter_widget = jupyter_widget
        self.jupyter_widget.execute("%matplotlib inline")
        self.grid_layout = QGridLayout()
        self.grid_layout.addWidget(self.jupyter_widget, 0, 0, -1, -1)
        self.setLayout(self.grid_layout)

    def close(self):
        self.jupyter_widget.kernel_client.stop_channels()
        self.jupyter_widget.kernel_manager.shutdown_kernel()
        super().close()
